==> syncope-3.0.2-source-release.zip: syncope-3.0.2/wa/starter/src/main/java/org/apache/syncope/wa/starter/mapping/RemoteEndpointAccessMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.wa.starter.mapping;

import java.util.Optional;
import org.apache.syncope.common.lib.policy.AccessPolicyTO;
import org.apache.syncope.common.lib.policy.RemoteEndpointAccessPolicyConf;
import org.apereo.cas.services.RegisteredServiceAccessStrategy;
import org.apereo.cas.services.RemoteEndpointServiceAccessStrategy;

@AccessMapFor(accessPolicyConfClass = RemoteEndpointAccessPolicyConf.class)
public class RemoteEndpointAccessMapper implements AccessMapper {

    @Override
    public RegisteredServiceAccessStrategy build(final AccessPolicyTO policy) {
        RemoteEndpointAccessPolicyConf conf = (RemoteEndpointAccessPolicyConf) policy.getConf();

        RemoteEndpointServiceAccessStrategy accessStrategy = new RemoteEndpointServiceAccessStrategy();

        Optional.ofNullable(conf.getEndpointUrl()).ifPresent(accessStrategy::setEndpointUrl);

        accessStrategy.setAcceptableResponseCodes(String.join(",", conf.getAcceptableResponseCodes()));

        return accessStrategy;
    }
}

==> syncope-4.0.3-source-release.zip: syncope-4.0.3/wa/starter/src/main/java/org/apache/syncope/wa/starter/mapping/RemoteEndpointAccessMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.wa.starter.mapping;

import java.util.Optional;
import org.apache.syncope.common.lib.policy.AccessPolicyConf;
import org.apache.syncope.common.lib.policy.AccessPolicyTO;
import org.apache.syncope.common.lib.policy.RemoteEndpointAccessPolicyConf;
import org.apereo.cas.services.RegisteredServiceAccessStrategy;
import org.apereo.cas.services.RemoteEndpointServiceAccessStrategy;

public class RemoteEndpointAccessMapper implements AccessMapper {

    @Override
    public boolean supports(final AccessPolicyConf conf) {
        return RemoteEndpointAccessPolicyConf.class.equals(conf.getClass());
    }

    @Override
    public RegisteredServiceAccessStrategy build(final AccessPolicyTO policy) {
        RemoteEndpointAccessPolicyConf conf = (RemoteEndpointAccessPolicyConf) policy.getConf();

        RemoteEndpointServiceAccessStrategy accessStrategy = new RemoteEndpointServiceAccessStrategy();

        Optional.ofNullable(conf.getEndpointUrl()).ifPresent(accessStrategy::setEndpointUrl);

        accessStrategy.setAcceptableResponseCodes(String.join(",", conf.getAcceptableResponseCodes()));

        return accessStrategy;
    }
}
